#region Using

using System;
using System.IO;
using System.Net;
using System.Web;
using System.Text;

#endregion

/// <summary>
/// Provide a way to send RPC requests and get the response.
/// </summary>
public static class RpcService
{

	/// <summary>
	/// The HTTP method used to send HTTP requests.
	/// </summary>
	public enum HttpMethod
	{
		POST,
		GET
	}

	/// <summary>
	/// Sends a request with the specified text in the request stream.
	/// </summary>
	/// <param name="url">The URL to send the request to.</param>
	/// <param name="text">The text to pass in the request stream</param>
	/// <param name="method">The HTTP method used to send the request.</param>
	/// <returns>The text from the response stream.</returns>
	public static string Send(Uri url, string text, HttpMethod method)
	{
		HttpWebRequest request = (HttpWebRequest)HttpWebRequest.Create(url);
		request.Credentials = CredentialCache.DefaultNetworkCredentials;
		request.Method = method.ToString();
		request.Timeout = 10000;
		request.ContentType = "text/xml";
		request.ProtocolVersion = HttpVersion.Version11;

		Stream requestStream = (Stream)request.GetRequestStream();
		using (StreamWriter writer = new StreamWriter(requestStream))
		{
			writer.Write(text);
		}

		return RetrieveResponse(request);
	}

	/// <summary>
	/// Receives this content from the current HTTP request stream.
	/// </summary>
	public static string Receive()
	{
		using (StreamReader reader = new StreamReader(HttpContext.Current.Request.InputStream))
		{
			return reader.ReadToEnd();
		}
	}

	/// <summary>
	/// Retrieves the response sent by the requested URL.
	/// </summary>
	private static string RetrieveResponse(HttpWebRequest request)
	{
		using (HttpWebResponse response = (HttpWebResponse)request.GetResponse())
		{
			Stream responseStream = (Stream)response.GetResponseStream();

			using (StreamReader reader = new StreamReader(responseStream, true))
			{
				return reader.ReadToEnd();
			}
		}
	}

}